@@ -2,7 +2,8 @@ use serde::Serialize;
 use std::collections::VecDeque;
 use toml::value::Table;
 
-#[derive(Serialize, Debug)]
+#[derive(Serialize, Debug, Default)]
+#[must_use]
 pub struct BuildPlan {
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub provides: Vec<Provide>,
@@ -13,22 +14,13 @@ pub struct BuildPlan {
 }
 
 impl BuildPlan {
-    #[must_use]
     pub fn new() -> Self {
-        Self {
-            provides: vec![],
-            requires: vec![],
-            or: vec![],
-        }
-    }
-}
-
-impl Default for BuildPlan {
-    fn default() -> Self {
-        Self::new()
+        Self::default()
     }
 }
 
+#[derive(Default)]
+#[must_use]
 pub struct BuildPlanBuilder {
     acc: VecDeque<(Vec<Provide>, Vec<Require>)>,
     current_provides: Vec<Provide>,
@@ -36,13 +28,8 @@ pub struct BuildPlanBuilder {
 }
 
 impl BuildPlanBuilder {
-    #[must_use]
     pub fn new() -> Self {
-        Self {
-            acc: VecDeque::new(),
-            current_provides: vec![],
-            current_requires: vec![],
-        }
+        Self::default()
     }
 
     pub fn provides(mut self, name: impl AsRef<str>) -> Self {
@@ -55,7 +42,6 @@ impl BuildPlanBuilder {
         self
     }
 
-    #[must_use]
     pub fn or(mut self) -> Self {
         self.acc
             .push_back((self.current_provides, self.current_requires));
@@ -65,7 +51,6 @@ impl BuildPlanBuilder {
         self
     }
 
-    #[must_use]
     pub fn build(self) -> BuildPlan {
         let mut xyz = self.or();
 
@@ -88,12 +73,6 @@ impl BuildPlanBuilder {
     }
 }
 
-impl Default for BuildPlanBuilder {
-    fn default() -> Self {
-        Self::new()
-    }
-}
-
 #[derive(Serialize, Debug)]
 pub struct Or {
     #[serde(skip_serializing_if = "Vec::is_empty")]
