@@ -2,7 +2,7 @@ use crate::bom;
 use crate::newtypes::libcnb_newtype;
 use serde::{Deserialize, Serialize};
 
-#[derive(Deserialize, Serialize, Debug)]
+#[derive(Deserialize, Serialize, Debug, Default)]
 #[serde(deny_unknown_fields)]
 pub struct Launch {
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
@@ -33,12 +33,7 @@ pub struct Launch {
 impl Launch {
     #[must_use]
     pub fn new() -> Self {
-        Self {
-            bom: bom::Bom::new(),
-            labels: Vec::new(),
-            processes: Vec::new(),
-            slices: Vec::new(),
-        }
+        Self::default()
     }
 
     #[must_use]
@@ -48,12 +43,6 @@ impl Launch {
     }
 }
 
-impl Default for Launch {
-    fn default() -> Self {
-        Self::new()
-    }
-}
-
 #[derive(Deserialize, Serialize, Debug)]
 #[serde(deny_unknown_fields)]
 pub struct Label {
